@@ -1,7 +1,7 @@
 package Yars::Routes;
 
 # ABSTRACT: set up the routes for Yars.
-our $VERSION = '0.80_02'; # VERSION
+our $VERSION = '0.80_03'; # VERSION
 
 
 use strict;
@@ -20,9 +20,6 @@ use List::MoreUtils qw/uniq/;
 use Digest::file qw/digest_file_hex/;
 use File::Basename qw/basename/;
 
-# default max download size of 50 GB
-$ENV{MOJO_MAX_MESSAGE_SIZE} ||= 1073741824 * 50;
-
 ladder sub {
  my $c = shift;
  Yars::Tools->refresh_config($c->config);
@@ -605,7 +602,7 @@ Yars::Routes - set up the routes for Yars.
 
 =head1 VERSION
 
-version 0.80_02
+version 0.80_03
 
 =head1 ROUTES
 
